from distutils.core import setup

setup(
    name='tinmanlol',
    version='1.2.0',
    py_modules=['tinmanlol'],
    author='Tinman',
    author_email='dingding2627@sohu.com',
    url='https://user.qzone.qq.com/339526812/infocenter',
    description='A simple printer of nested lists',
    )